@@ -2,7 +2,7 @@
  * userv - acconfig.h
  * extra stuff for config.h.in (autoconf)
  *
- * Copyright (C)1996-1997 Ian Jackson
+ * Copyright (C)1996-1997,1999 Ian Jackson
  *
  * This is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
@@ -22,6 +22,12 @@
 /* Define if EPROTO exists.  */
 #undef HAVE_EPROTO
 
+/* Define if LOG_AUTHPRIV exists.  */
+#undef HAVE_LOG_AUTHPRIV
+
+/* Define if WCOREDUMP exists.  */
+#undef HAVE_WCOREDUMP
+
 /* Define if function attributes a la GCC 2.5 and higher are available.  */
 #undef HAVE_GNUC25_ATTRIB
 
@@ -36,11 +42,31 @@
 
 @BOTTOM@
 
+/* STRSIGNAL */
+#ifndef HAVE_STRSIGNAL
+#define STRSIGNAL(x) "[platform has no strsignal!]"
+#endif
+
+/* VSNPRINTF */
+#ifndef HAVE_VSNPRINTF
+# error "You must have vsnprintf!  Without vsnprintf it is very hard to write secure programs.  If you don't have it then your system libc is probably full of hideous buffer overrun security bugs.  But, if you don't want to fix your system a portable snprintf can be found at http://www.ijs.si/software/snprintf/"
+#endif
+
 /* EPROTO */
 #ifndef HAVE_EPROTO
 #define EPROTO 0
 #endif
 
+/* LOG_AUTHPRIV */
+#ifndef HAVE_LOG_AUTHPRIV
+#define LOG_AUTHPRIV LOG_AUTH
+#endif
+
+/* WCOREDUMP */
+#ifndef HAVE_WCOREDUMP
+#define WCOREDUMP(x) 0
+#endif
+
 /* GNU C attributes. */
 #ifndef FUNCATTR
 #ifdef HAVE_GNUC25_ATTRIB
