@@ -433,8 +433,7 @@ static void usage(FILE *stream) {
     "userv -B 'X' ... is same as userv --override 'execute-builtin X' - 'X' ...\n"
     "         for help, type `userv -B help'; remember to quote multi-word X\n"
     "userv and uservd version " VERSION VEREXT ".\n"
-    "Copyright (C)1996-2003,2006 Ian Jackson; copyright (C)2000 Ben Harris.\n"
-    "there is NO WARRANTY; type `userv --copyright' for details.\n",
+    COPYRIGHT("","\n"),
             stream) < 0)
     syscallerror("write usage message");
 }
@@ -726,7 +725,9 @@ static void of_version(const struct optioninfo *oip, const char *value, char *ke
 
 static void of_copyright(const struct optioninfo *oip, const char *value, char *key) {
   if (fputs(
-" userv - user service daemon and client; copyright (C)1996-1999 Ian Jackson\n\n"
+" userv - user service daemon and client\n\n"
+COPYRIGHT(" ","\n")
+"\n"
 " This is free software; you can redistribute it and/or modify it under the\n"
 " terms of the GNU General Public License as published by the Free Software\n"
 " Foundation; either version 2 of the License, or (at your option) any\n"
@@ -736,9 +737,7 @@ static void of_copyright(const struct optioninfo *oip, const char *value, char *
 " MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General\n"
 " Public License for more details.\n\n"
 " You should have received a copy of the GNU General Public License along\n"
-" with userv; if not, write to Ian Jackson <ian@davenant.greenend.org.uk> or\n"
-" to the Free Software Foundation, 59 Temple Place - Suite 330, Boston,\n"
-" MA 02111-1307, USA.\n",
+" with userv; if not, see <http://www.gnu.org/licenses/>.\n",
 	    stdout) < 0) syscallerror("write usage to stderr");
   exit(0);
 }
