@@ -98,61 +98,62 @@ enum tokens {
   toki_word_version=                                0x0000002d,
   toki_word_toplevel=                               0x0000002e,
   toki_word_override=                               0x0000002f,
-  toki_word_reset=                                  0x00000030,
-  toki_word_execute=                                0x00000031,
-  toki_word_help=                                   0x00000032,
-  toki_word_service=                                0x00000033,
-  toki_word_callinguser=                            0x00000034,
-  toki_word_callinggroup=                           0x00000035,
-  toki_word_callingusershell=                       0x00000036,
-  toki_word_serviceuser=                            0x00000037,
-  toki_word_servicegroup=                           0x00000038,
-  toki_word_serviceusershell=                       0x00000039,
-  toki_syslog_debug=                                0x0000003a,
-  toki_syslog_info=                                 0x0000003b,
-  toki_syslog_notice=                               0x0000003c,
-  toki_syslog_warning=                              0x0000003d,
-  toki_syslog_err=                                  0x0000003e,
-  toki_syslog_crit=                                 0x0000003f,
-  toki_syslog_alert=                                0x00000040,
-  toki_syslog_emerg=                                0x00000041,
-  toki_syslog_authpriv=                             0x00000042,
-  toki_syslog_cron=                                 0x00000043,
-  toki_syslog_daemon=                               0x00000044,
-  toki_syslog_kern=                                 0x00000045,
-  toki_syslog_lpr=                                  0x00000046,
-  toki_syslog_mail=                                 0x00000047,
-  toki_syslog_news=                                 0x00000048,
-  toki_syslog_syslog=                               0x00000049,
-  toki_syslog_user=                                 0x0000004a,
-  toki_syslog_uucp=                                 0x0000004b,
-  toki_syslog_local0=                               0x0000004c,
-  toki_syslog_local1=                               0x0000004d,
-  toki_syslog_local2=                               0x0000004e,
-  toki_syslog_local3=                               0x0000004f,
-  toki_syslog_local4=                               0x00000050,
-  toki_syslog_local5=                               0x00000051,
-  toki_syslog_local6=                               0x00000052,
-  toki_syslog_local7=                               0x00000053,
-  toki_word_read=                                   0x00000054,
-  toki_word_write=                                  0x00000055,
-  toki_ordinal=                                     0x00000056,
-  toki_fdrange=                                     0x00000057,
-  toki_fdstoend=                                    0x00000058,
-  toki_dollar=                                      0x00000059,
-  toki_lwsp=                                        0x0000005a,
-  toki_newline=                                     0x0000005b,
-  toki_barestring=                                  0x0000005c,
-  toki_quotedstring=                                0x0000005d,
-  toki_eof=                                         0x0000005e,
-  toki_quit=                                        0x0000005f,
-  toki_error=                                       0x00000060,
-  toki_openparen=                                   0x00000061,
-  toki_closeparen=                                  0x00000062,
-  toki_not=                                         0x00000063,
-  toki_and=                                         0x00000064,
-  toki_or=                                          0x00000065,
-  toki_word_error=                                  0x00000066,
+  toki_word_shutdown=                               0x00000030,
+  toki_word_reset=                                  0x00000031,
+  toki_word_execute=                                0x00000032,
+  toki_word_help=                                   0x00000033,
+  toki_word_service=                                0x00000034,
+  toki_word_callinguser=                            0x00000035,
+  toki_word_callinggroup=                           0x00000036,
+  toki_word_callingusershell=                       0x00000037,
+  toki_word_serviceuser=                            0x00000038,
+  toki_word_servicegroup=                           0x00000039,
+  toki_word_serviceusershell=                       0x0000003a,
+  toki_syslog_debug=                                0x0000003b,
+  toki_syslog_info=                                 0x0000003c,
+  toki_syslog_notice=                               0x0000003d,
+  toki_syslog_warning=                              0x0000003e,
+  toki_syslog_err=                                  0x0000003f,
+  toki_syslog_crit=                                 0x00000040,
+  toki_syslog_alert=                                0x00000041,
+  toki_syslog_emerg=                                0x00000042,
+  toki_syslog_authpriv=                             0x00000043,
+  toki_syslog_cron=                                 0x00000044,
+  toki_syslog_daemon=                               0x00000045,
+  toki_syslog_kern=                                 0x00000046,
+  toki_syslog_lpr=                                  0x00000047,
+  toki_syslog_mail=                                 0x00000048,
+  toki_syslog_news=                                 0x00000049,
+  toki_syslog_syslog=                               0x0000004a,
+  toki_syslog_user=                                 0x0000004b,
+  toki_syslog_uucp=                                 0x0000004c,
+  toki_syslog_local0=                               0x0000004d,
+  toki_syslog_local1=                               0x0000004e,
+  toki_syslog_local2=                               0x0000004f,
+  toki_syslog_local3=                               0x00000050,
+  toki_syslog_local4=                               0x00000051,
+  toki_syslog_local5=                               0x00000052,
+  toki_syslog_local6=                               0x00000053,
+  toki_syslog_local7=                               0x00000054,
+  toki_word_read=                                   0x00000055,
+  toki_word_write=                                  0x00000056,
+  toki_ordinal=                                     0x00000057,
+  toki_fdrange=                                     0x00000058,
+  toki_fdstoend=                                    0x00000059,
+  toki_dollar=                                      0x0000005a,
+  toki_lwsp=                                        0x0000005b,
+  toki_newline=                                     0x0000005c,
+  toki_barestring=                                  0x0000005d,
+  toki_quotedstring=                                0x0000005e,
+  toki_eof=                                         0x0000005f,
+  toki_quit=                                        0x00000060,
+  toki_error=                                       0x00000061,
+  toki_openparen=                                   0x00000062,
+  toki_closeparen=                                  0x00000063,
+  toki_not=                                         0x00000064,
+  toki_and=                                         0x00000065,
+  toki_or=                                          0x00000066,
+  toki_word_error=                                  0x00000067,
 
   tokv_word_reject=             tokt_directive|tokt_execmode|tokr_word|toki_word_reject,
   tokv_word_executefromdirectory=tokt_directive|tokt_execmode|tokr_word|toki_word_executefromdirectory,
@@ -201,6 +202,7 @@ enum tokens {
   tokv_word_version=            tokt_builtinservice|tokr_word|toki_word_version,
   tokv_word_toplevel=           tokt_builtinservice|tokr_word|toki_word_toplevel,
   tokv_word_override=           tokt_builtinservice|tokr_word|toki_word_override,
+  tokv_word_shutdown=           tokt_builtinservice|tokr_word|toki_word_shutdown,
   tokv_word_reset=              tokt_builtinservice|tokt_directive|tokr_word|toki_word_reset,
   tokv_word_execute=            tokt_builtinservice|tokt_directive|tokt_execmode|tokr_word|toki_word_execute,
   tokv_word_help=               tokt_builtinservice|tokr_word|toki_word_help,
